=====
Kazoo
=====

.. image:: https://travis-ci.org/python-zk/kazoo.svg?branch=master
    :target: https://travis-ci.org/python-zk/kazoo
    :alt: Travis Build

.. image:: https://img.shields.io/pypi/v/kazoo.svg
    :target: https://pypi.python.org/pypi/kazoo/
    :alt: Latest Version

.. image:: https://img.shields.io/pypi/dm/kazoo.svg
    :target: https://pypi.python.org/pypi/kazoo/
    :alt: Downloads

``kazoo`` implements a higher level API to `Apache Zookeeper`_ for Python
clients.

See `the full docs`_ for more information.

License
=======

``kazoo`` is offered under the Apache License 2.0.

Authors
=======

``kazoo`` started under the `Nimbus Project`_ and through collaboration with
the open-source community has been merged with code from `Mozilla`_ and the
`Zope Corporation`_. It has since gathered an active community of over two
dozen contributors.

.. _Apache Zookeeper: http://zookeeper.apache.org/
.. _the full docs: http://kazoo.rtfd.org/
.. _Nimbus Project: http://www.nimbusproject.org/
.. _Zope Corporation: http://zope.com/
.. _Mozilla: http://www.mozilla.org/
